import 'package:flutter/material.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:senior_design_system/senior_design_system.dart';
import '../page_wrapper.dart';
import '../panel.dart';

class CardExample extends StatefulWidget {
  const CardExample({Key? key}) : super(key: key);

  @override
  _CardExampleState createState() => _CardExampleState();
}

class _CardExampleState extends State<CardExample> {
  bool _isCheck = false;

  void _showSnackbar({
    required BuildContext context,
    required String message,
  }) {
    final scaffold = ScaffoldMessenger.of(context);
    scaffold.showSnackBar(
      SnackBar(
        content: Text(message),
      ),
    );
  }

  Widget buildContent() {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Text(
          'Saldo',
          style: SeniorTypography.small(
            color: SeniorColors.neutralColor600,
          ),
        ),
        Padding(
          padding: const EdgeInsets.all(16.0),
          child: Row(
            mainAxisAlignment: MainAxisAlignment.start,
            crossAxisAlignment: CrossAxisAlignment.end,
            children: [
              Text(
                'R\$',
                style: SeniorTypography.tiny(
                  color: SeniorColors.neutralColor600,
                ),
              ),
              Text(
                '145.743.187,57',
                style: SeniorTypography.h3(
                  color: SeniorColors.secondaryColor900,
                ),
              ),
            ],
          ),
        ),
        Text(
          'últimos 30 dias',
          style: SeniorTypography.text(
            color: SeniorColors.secondaryColor800,
          ),
        ),
      ],
    );
  }

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Card Example',
      content: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.all(16.0),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.stretch,
            children: [
              Panel(
                title: 'Push',
                content: SeniorCard(
                  severityColor: SeniorColors.secondaryColor500,
                  pushAction: () {
                    _showSnackbar(
                        context: context, message: 'Ação do primeiro card');
                  },
                  content: buildContent(),
                ),
              ),
              Panel(
                title: 'Checkbox',
                content: SeniorCard.checkbox(
                  onCheck: (value) {
                    if (value == null) return;
                    setState(() {
                      _isCheck = value;
                    });
                  },
                  value: _isCheck,
                  severityColor: SeniorColors.primaryColor400,
                  pushAction: () {
                    _showSnackbar(
                        context: context, message: 'Ação do segundo card');
                  },
                  content: buildContent(),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
