import 'package:flutter/material.dart';
import 'package:senior_design_system/senior_design_system.dart';
import '../page_wrapper.dart';
import '../panel.dart';

class CheckboxExample extends StatefulWidget {
  const CheckboxExample({Key? key}) : super(key: key);

  @override
  _CheckboxExampleState createState() => _CheckboxExampleState();
}

class _CheckboxExampleState extends State<CheckboxExample> {
  bool _isDisabled = false;
  bool _optionOne = false;
  bool _optionTwo = false;
  bool _optionThree = false;
  bool _optionFour = false;

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Checkbox Example',
      content: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.only(top: 16.0),
          child: Column(
            children: [
              SeniorSwitch(
                title: 'Habilitar botões',
                value: !this._isDisabled,
                onChanged: (value) {
                  if (value == null) return;
                  setState(() {
                    this._isDisabled = !value;
                  });
                },
                labelPosition: SeniorSwitchLabelPosition.right,
              ),
              Padding(
                padding: const EdgeInsets.all(16.0),
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    Panel(
                      title: 'Normal',
                      content: Column(
                        children: [
                          SeniorCheckbox(
                            title: 'Matutino',
                            value: this._optionOne,
                            onChanged: (value) {
                              if (value == null) return;
                              setState(() {
                                this._optionOne = value;
                              });
                            },
                            disabled: this._isDisabled,
                          ),
                          SeniorCheckbox(
                            title: 'Vespertino',
                            value: this._optionTwo,
                            onChanged: (value) {
                              if (value == null) return;
                              setState(() {
                                this._optionTwo = value;
                              });
                            },
                            disabled: this._isDisabled,
                          ),
                          SeniorCheckbox(
                            title: 'Noturno',
                            value: this._optionThree,
                            onChanged: (value) {
                              if (value == null) return;
                              setState(() {
                                this._optionThree = value;
                              });
                            },
                            disabled: this._isDisabled,
                          ),
                        ],
                      ),
                    ),
                    Panel(
                      title: 'Sem label',
                      content: SeniorCheckbox(
                        value: this._optionOne,
                        onChanged: (value) {
                          if(value == null) return;
                          setState(() {
                            this._optionOne = value;
                          });
                        },
                        disabled: this._isDisabled,
                      ),
                    ),
                    Panel(
                      title: 'Botões em linha',
                      content: Row(
                        children: [
                          Expanded(
                            child: SeniorCheckbox(
                              title: 'Esquerda',
                              value: this._optionOne,
                              onChanged: (value) {
                                if (value == null) return;
                                setState(() {
                                  this._optionOne = value;
                                });
                              },
                              disabled: this._isDisabled,
                            ),
                          ),
                          Expanded(
                            child: SeniorCheckbox(
                              title: 'Centro',
                              value: this._optionTwo,
                              onChanged: (value) {
                                if (value == null) return;
                                setState(() {
                                  this._optionTwo = value;
                                });
                              },
                              disabled: this._isDisabled,
                            ),
                          ),
                          Expanded(
                            child: SeniorCheckbox(
                              title: 'Direita',
                              value: this._optionThree,
                              onChanged: (value) {
                                if (value == null) return;
                                setState(() {
                                  this._optionThree = value;
                                });
                              },
                              disabled: this._isDisabled,
                            ),
                          ),
                        ],
                      ),
                    ),
                    Panel(
                      title: 'Botões em colunas separadas',
                      content: Column(
                        children: [
                          Row(
                            children: [
                              Expanded(
                                child: SeniorCheckbox(
                                  title: 'Brasil',
                                  value: this._optionOne,
                                  onChanged: (value) {
                                    if (value == null) return;
                                    setState(() {
                                      this._optionOne = value;
                                    });
                                  },
                                  disabled: this._isDisabled,
                                ),
                              ),
                              Expanded(
                                child: SeniorCheckbox(
                                  title: 'Argentina',
                                  value: this._optionTwo,
                                  onChanged: (value) {
                                    if (value == null) return;
                                    setState(() {
                                      this._optionTwo = value;
                                    });
                                  },
                                  disabled: this._isDisabled,
                                ),
                              ),
                            ],
                          ),
                          Row(
                            children: [
                              Expanded(
                                child: SeniorCheckbox(
                                  title: 'Colômbia',
                                  value: this._optionThree,
                                  onChanged: (value) {
                                    if (value == null) return;
                                    setState(() {
                                      this._optionThree = value;
                                    });
                                  },
                                  disabled: this._isDisabled,
                                ),
                              ),
                              Expanded(
                                child: SeniorCheckbox(
                                  title: 'Peru',
                                  value: this._optionFour,
                                  onChanged: (value) {
                                    if (value == null) return;
                                    setState(() {
                                      this._optionFour = value;
                                    });
                                  },
                                  disabled: this._isDisabled,
                                ),
                              ),
                            ],
                          )
                        ],
                      ),
                    ),
                  ],
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
