import 'package:flutter/material.dart';
import 'package:senior_design_system/senior_design_system.dart';
import '../page_wrapper.dart';
import '../panel.dart';

class RadioButtonExample extends StatefulWidget {
  const RadioButtonExample({Key? key}) : super(key: key);

  @override
  _RadioButtonExampleState createState() => _RadioButtonExampleState();
}

class _RadioButtonExampleState extends State<RadioButtonExample> {
  bool _isDisabled = false;
  String _optionOne = 'morning';
  String _optionTwo = 'left';
  String _optionThree = 'brazil';

  void _changeOptionOne(dynamic value) {
    setState(() {
      this._optionOne = value as String;
    });
  }

  void _changeOptionTwo(dynamic value) {
    setState(() {
      this._optionTwo = value as String;
    });
  }

  void _changeOptionThree(dynamic value) {
    setState(() {
      this._optionThree = value as String;
    });
  }

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Radio Button Example',
      content: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.only(top: 16.0),
          child: Container(
            child: Column(
              children: [
                SeniorSwitch(
                  title: 'Habilitar botões',
                  value: !this._isDisabled,
                  onChanged: (value) {
                    if (value == null) return;
                    setState(() {
                      this._isDisabled = !value;
                    });
                  },
                  labelPosition: SeniorSwitchLabelPosition.right,
                ),
                Padding(
                  padding: const EdgeInsets.all(16.0),
                  child: Column(
                    children: [
                      Panel(
                        title: 'Normal',
                        content: Column(
                          children: [
                            SeniorRadioButton<dynamic>(
                              title: 'Matutino',
                              groupValue: this._optionOne,
                              value: 'morning',
                              onChange: this._changeOptionOne,
                              disabled: this._isDisabled,
                            ),
                            SeniorRadioButton<dynamic>(
                              title: 'Vespertino',
                              groupValue: this._optionOne,
                              value: 'afternoon',
                              onChange: this._changeOptionOne,
                              disabled: this._isDisabled,
                            ),
                            SeniorRadioButton<dynamic>(
                              title: 'Noturno',
                              groupValue: this._optionOne,
                              value: 'night',
                              onChange: this._changeOptionOne,
                              disabled: this._isDisabled,
                            ),
                          ],
                        ),
                      ),
                      Panel(
                        title: 'Botões em linha',
                        content: Row(
                          children: [
                            Expanded(
                              child: SeniorRadioButton<dynamic>(
                                title: 'Esquerda',
                                groupValue: this._optionTwo,
                                value: 'left',
                                onChange: this._changeOptionTwo,
                                disabled: this._isDisabled,
                              ),
                            ),
                            Expanded(
                              child: SeniorRadioButton<dynamic>(
                                title: 'Centro',
                                groupValue: this._optionTwo,
                                value: 'center',
                                onChange: this._changeOptionTwo,
                                disabled: this._isDisabled,
                              ),
                            ),
                            Expanded(
                              child: SeniorRadioButton<dynamic>(
                                title: 'Direita',
                                groupValue: this._optionTwo,
                                value: 'right',
                                onChange: this._changeOptionTwo,
                                disabled: this._isDisabled,
                              ),
                            ),
                          ],
                        ),
                      ),
                      Panel(
                        title: 'Botões em colunas separadas',
                        content: Column(
                          children: [
                            Row(
                              children: [
                                Expanded(
                                  child: SeniorRadioButton<dynamic>(
                                    title: 'Brasil',
                                    groupValue: this._optionThree,
                                    value: 'brazil',
                                    onChange: this._changeOptionThree,
                                    disabled: this._isDisabled,
                                  ),
                                ),
                                Expanded(
                                  child: SeniorRadioButton<dynamic>(
                                    title: 'Argentina',
                                    groupValue: this._optionThree,
                                    value: 'argentina',
                                    onChange: this._changeOptionThree,
                                    disabled: this._isDisabled,
                                  ),
                                ),
                              ],
                            ),
                            Row(
                              children: [
                                Expanded(
                                  child: SeniorRadioButton<dynamic>(
                                    title: 'Colômbia',
                                    groupValue: this._optionThree,
                                    value: 'colombia',
                                    onChange: this._changeOptionThree,
                                    disabled: this._isDisabled,
                                  ),
                                ),
                                Expanded(
                                  child: SeniorRadioButton<dynamic>(
                                    title: 'Peru',
                                    groupValue: this._optionThree,
                                    value: 'peru',
                                    onChange: this._changeOptionThree,
                                    disabled: this._isDisabled,
                                  ),
                                ),
                              ],
                            ),
                          ],
                        ),
                      ),
                    ],
                  ),
                ),
              ],
            ),
          ),
        ),
      ),
    );
  }
}
