import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

class SeniorMenuItemList extends StatelessWidget {
  const SeniorMenuItemList({
    Key? key,
    required this.iconData,
    required this.title,
    this.onTap,
    this.subtitle,
    this.enabled = true,
  }) : super(key: key);

  final IconData iconData;
  final String title;
  final String? subtitle;
  final VoidCallback? onTap;
  final bool enabled;

  @override
  Widget build(BuildContext context) {
    return Material(
      color: Colors.transparent,
      child: InkWell(
        onTap: enabled ? onTap : null,
        child: Container(
          padding: EdgeInsets.only(
            left: 25,
            top: 10,
            bottom: 10,
            right: 23.75,
          ),
          child: Row(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Padding(
                padding: const EdgeInsets.only(
                  right: 12.0,
                ),
                child: Icon(
                  iconData,
                  size: 20,
                  color: SeniorColors.primaryColor500,
                ),
              ),
              Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                mainAxisAlignment: MainAxisAlignment.start,
                children: [
                  Text(
                    title,
                    textAlign: TextAlign.left,
                    style: SeniorTypography.body(
                      color: SeniorColors.primaryColor900,
                    ),
                  ),
                  subtitle == null
                      ? SizedBox.shrink()
                      : Text(
                          subtitle!,
                          textAlign: TextAlign.left,
                          style: SeniorTypography.body(
                            color: SeniorColors.primaryColor900,
                          ),
                        ),
                ],
              ),
              Spacer(),
              Offstage(
                offstage: onTap == null,
                child: Align(
                  alignment: Alignment.center,
                  child: Icon(
                    FontAwesomeIcons.angleRight,
                    color: enabled
                      ? SeniorColors.primaryColor500
                      : SeniorColors.neutralColor900,
                    size: 20,
                  ),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
