import 'package:flutter/material.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

class SeniorQuotes extends StatelessWidget {
  final String message;
  final bool? isScrollable;
  SeniorQuotes({Key? key, required this.message, this.isScrollable = false})
      : super(key: key);

  final ScrollController scrollController = ScrollController();

  @override
  Widget build(BuildContext context) {
    return isScrollable! ? buildQuotes() : buildExpandedQuotes();
  }

  Widget buildQuotes() {
    return Expanded(
      child: Container(
        margin: const EdgeInsets.only(
          right: SeniorSpacing.normal,
          left: SeniorSpacing.normal,
        ),
        width: double.infinity,
        decoration: BoxDecoration(
          color: SeniorColors.secondaryColor100,
          borderRadius: BorderRadius.circular(6.0),
        ),
        child: Stack(
          children: [
            Padding(
              padding: EdgeInsets.only(
                top: 55.0,
                bottom: 50.0,
                right: 5.0,
              ),
              child: Scrollbar(
                isAlwaysShown: true,
                thickness: 5.0,
                controller: scrollController,
                radius: Radius.circular(6.0),
                child: SingleChildScrollView(
                  controller: scrollController,
                  padding: EdgeInsets.symmetric(
                    horizontal: 40.0,
                  ),
                  physics: BouncingScrollPhysics(),
                  child: Text(
                    message,
                    style: SeniorTypography.text(
                      color: SeniorColors.neutralColor800,
                    ),
                  ),
                ),
              ),
            ),
            Positioned(
              top: 20.0,
              left: 20.0,
              child: Text(
                '“',
                style: SeniorTypography.h1(),
              ),
            ),
            Positioned(
              bottom: 0.0,
              right: 20.0,
              child: Text(
                '”',
                style: SeniorTypography.h1(),
              ),
            ),
          ],
        ),
      ),
    );
  }

  Widget buildExpandedQuotes() {
    return Container(
      decoration: BoxDecoration(
        color: SeniorColors.secondaryColor100,
        borderRadius: BorderRadius.circular(6.0),
      ),
      child: Stack(
        children: [
          Padding(
            padding: EdgeInsets.only(
              top: 55.0,
              bottom: 50.0,
              right: 40.0,
              left: 40.0,
            ),
            child: Text(
              message,
              style: SeniorTypography.text(
                color: SeniorColors.neutralColor800,
              ),
            ),
          ),
          Positioned(
            top: 20.0,
            left: 20.0,
            child: Text(
              '“',
              style: SeniorTypography.h1(),
            ),
          ),
          Positioned(
            bottom: 0.0,
            right: 20.0,
            child: Text(
              '”',
              style: SeniorTypography.h1(),
            ),
          ),
        ],
      ),
    );
  }
}
