import 'package:flutter/material.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

class SeniorTabBarTheme {
  SeniorTabBarTheme._();

  static Color getUnselectedLabelColor({ required Brightness theme }) {
    return SeniorColors.neutralColor500;
  }

  static Color getIndicatorColor({ required Brightness theme }) {
    return SeniorColors.primaryColor;
  }

  static Color getLabelColor({ required Brightness theme }) {
    return SeniorColors.neutralColor800;
  }
}

class SeniorTabBar extends StatelessWidget implements PreferredSizeWidget {
  final List<String> tabs;
  final int initialIndex;
  final bool isScrollable;
  final Function(int) onTap;
  final TabController? controller;

  const SeniorTabBar({
    Key? key,
    required this.tabs,
    required this.initialIndex,
    required this.onTap,
    this.isScrollable = false,
    this.controller,
  }) : super(key: key);

  @override
  Size get preferredSize => const Size.fromHeight(100.0);

  @override
  Widget build(BuildContext context) {
    Brightness theme = MediaQuery.of(context).platformBrightness;

    return TabBar(
      tabs: this.tabs.map((tab) => Tab(text: tab)).toList(),
      labelColor: SeniorTabBarTheme.getLabelColor(theme: theme),
      unselectedLabelColor: SeniorTabBarTheme.getUnselectedLabelColor(theme: theme),
      indicatorColor: SeniorTabBarTheme.getIndicatorColor(theme: theme),
      labelStyle: SeniorTypography.body(
        color: SeniorTabBarTheme.getLabelColor(theme: theme),
      ),
      indicatorWeight: 2.0,
      isScrollable: this.isScrollable,
      onTap: this.onTap,
      controller: this.controller,        
    );
  }
}